Learn R Programming

pdmclass (version 1.44.0)

svdpls1c: Classify Microarray Data by Partial Least Squares

Description

This function is used by pdmClass and pdmGenes to classify microarray data by partial least squares. It is an internal function and not intended to be called by the end user.

Usage

svdpls1c(X, y, ...)

Arguments

X
A numeric matrix assumed to be centred so columns sum to zero.
y
A numeric vector assumed to sum to zero.
...
Further arguments to the function

Value

An object of class pls, containing the following items:
fitted.values
The fitted values.
coefficients
The model coefficients.
dimension
The number of PLS factors in the model.
xmeans
The sample means.

References

http://www.sph.umich.edu/~ghoshd/COMPBIO/POPTSCORE