svdpls1c: Classify Microarray Data by Partial Least Squares
Description
This function is used by pdmClass and pdmGenes to
classify microarray data by partial least squares. It is an
internal function and not intended to be called by the end user.
Usage
svdpls1c(X, y, ...)
Arguments
X
A numeric matrix assumed to be centred so columns sum to zero.
y
A numeric vector assumed to sum to zero.
...
Further arguments to the function
Value
An object of class pls, containing the following items: